@@ -5,6 +5,7 @@ https://wiki.mikrotik.com/wiki/Manual:API
 import asyncio
 from binascii import hexlify, unhexlify
 from collections import namedtuple
+from datetime import timedelta
 from hashlib import md5
 import itertools
 from keyword import iskeyword
@@ -12,17 +13,56 @@ import logging
 import ssl
 import struct
 
+UNIT_FIELDS = {
+    'w': 'weeks',
+    'd': 'days',
+    'h': 'hours',
+    'm': 'minutes',
+    's': 'seconds',
+    'ms': 'milliseconds'
+}
+
+
+def parse_api_timedelta(s):
+    """Parse the time delta format used in Mikrotik API, e.g. '2w1d2h21m2s120ms'.
+       This should never raise an error; it returns None if the string is bad."""
+    if not isinstance(s, str) or not s:
+        return None
+    parsed = {field: 0 for field in UNIT_FIELDS.values()}
+    i = 0
+    value = ''
+
+    try:
+        while i < len(s):
+            if s[i].isdigit():
+                value += s[i]
+                i += 1
+                continue
+
+            if not value:
+                return None
+
+            if s[i:i + 2] == 'ms':  # special case for 2 character string
+                unit = 'ms'
+                parsed['milliseconds'] += int(value)
+                i += 2
+            else:
+                unit = s[i]
+                i += 1
+
+            parsed[UNIT_FIELDS[unit]] += int(value)
+            value = ''
+
+        if value:
+            return None
+        return timedelta(**parsed)
+    except Exception:
+        return None
 
 class MikrotikApiError(Exception):
     pass
 
 
-# TODO unit testable.  Make test code able to replace with test data,
-# and some method to write test data.
-# Ideally test as much as possible, just stub out read/write from socket?
-# Maybe do a little stub server on localhost.
-
-
 class MikrotikApiClient:
     """Query the Mikrotik API"""
     _ssl_context = None
