@@ -1173,6 +1173,28 @@ class Radio(BaseWrapperClass):
                             value=value,
                             metric_name='NetworkElement.Radio.azimuth')
 
+    @property
+    def admin_up(self):
+        return self.pb.admin_up if self.pb.HasField('admin_up') else None
+
+    @admin_up.setter
+    def admin_up(self, value):
+        if value is not None:
+            self.pb.admin_up = value
+        else:
+            self.pb.ClearField('admin_up')
+
+    @property
+    def oper_up(self):
+        return self.pb.oper_up if self.pb.HasField('oper_up') else None
+
+    @oper_up.setter
+    def oper_up(self, value):
+        if value is not None:
+            self.pb.oper_up = value
+        else:
+            self.pb.ClearField('oper_up')
+
 
 @pb_wrapper(network_poller_pb2.NetworkElement.Sector)
 class Sector(BaseWrapperClass):
@@ -2436,6 +2458,17 @@ class NetworkElement(BaseWrapperClass):
         else:
             self.pb.admin_disabled = value
 
+    @property
+    def extra(self):
+        return self.pb.extra if self.pb.HasField('extra') else None
+
+    @extra.setter
+    def extra(self, value):
+        if value is not None:
+            self.pb.extra = value
+        else:
+            self.pb.ClearField('extra')
+
 
 @pb_wrapper(network_poller_pb2.NetworkElementUpdate)
 class NetworkElementUpdate(BaseWrapperClass):
